---
feature_story: FS_91_88_07_23
feature_title: jump tree
feature_status: TEST
---

This feature is related to:
*   FS_01_89_09_24 interp tre
*   FS_26_43_73_72 func tree

Jump tree allows overriding exiting tree path by another tree path
when current interp found a func (and, therefore, delegator) and selects next interp.

For example, it is used to continue completion from another part of the tree for functions like:
*   FS_71_87_33_52 `help_hint` func
*   FS_88_66_66_73 `intercept_invocation` func
